View source: R/appstream_operations.R
| appstream_create_export_image_task | R Documentation |
Creates a task to export a WorkSpaces Applications image to an EC2 AMI. This allows you to use your customized WorkSpaces Applications images with other AWS services or for backup purposes.
See https://www.paws-r-sdk.com/docs/appstream_create_export_image_task/ for full documentation.
appstream_create_export_image_task(
ImageName,
AmiName,
IamRoleArn,
TagSpecifications = NULL,
AmiDescription = NULL
)
ImageName |
[required] The name of the WorkSpaces Applications image to export. The image must be in an available state and owned by your account. |
AmiName |
[required] The name for the exported EC2 AMI. This is a required field that must be unique within your account and region. |
IamRoleArn |
[required] The ARN of the IAM role that allows WorkSpaces Applications to create the AMI. The role must have permissions to copy images, describe images, and create tags, with a trust relationship allowing appstream.amazonaws.com to assume the role. |
TagSpecifications |
The tags to apply to the exported AMI. These tags help you organize and manage your EC2 AMIs. |
AmiDescription |
An optional description for the exported AMI. This description will be applied to the resulting EC2 AMI. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.