Mark a user, group, or resource as no longer used in WorkMail. This action disassociates the mailbox and schedules it for clean-up. WorkMail keeps mailboxes for 30 days before they are permanently removed. The functionality in the console is Disable.
See https://www.paws-r-sdk.com/docs/workmail_deregister_from_work_mail/ for full documentation.
workmail_deregister_from_work_mail(OrganizationId, EntityId)[required] The identifier for the organization under which the WorkMail entity exists.
[required] The identifier for the member to be updated.
The identifier can be UserId, ResourceId, or Group Id, Username, Resourcename, or Groupname, or email.
Entity ID: 12345678-1234-1234-1234-123456789012, r-0123456789a0123456789b0123456789, or S-1-1-12-1234567890-123456789-123456789-1234
Email address: entity@domain.tld
Entity name: entity